@@ -287,7 +287,7 @@ class CinacPredictor:
 
     def predict(self, results_path, overlap_value=0.5, output_file_formats="npy", cell_type_classifier_mode=False,
                 n_segments_to_use_for_prediction=2, cell_type_pred_fct=np.mean, create_dir_for_results=True,
-                cell_buffer=None, all_pixels=True,
+                cell_buffer=None, all_pixels=True, time_verbose=True,
                 **kwargs):
         """
         Will predict the neural activity state of the cell for each frame of the calcium imaging movies.
@@ -313,10 +313,12 @@ class CinacPredictor:
             cell_buffer: None or int, distance in order to transform the cell contour giving an approximate
             representation of  all points within a given distance of the this geometric object
             all_pixels: bool, use for cell type prediction, add input with all pixels
+            time_verbose: if True, print the time to predict each cell
             **kwargs:
 
 
-        Returns: a dict with key being the id of the cinac recording and value:
+        Returns: a dict with key being a tuple with 2 string (the id of the cinac recording and the id of the
+         classifier used) and value:
         numpy array of n_cells containing the predictions (1d for cell activity, and 2d for cell type
         (n_cells, n_cell_types),.
 
@@ -422,7 +424,8 @@ class CinacPredictor:
                         predictions = predict_transient_from_model(cinac_recording=cinac_recording,
                                                                    cell=cell, model=model, overlap_value=overlap_value,
                                                                    use_data_augmentation=use_data_augmentation,
-                                                                   n_frames=n_frames, buffer=cell_buffer, pixels_around=0)
+                                                                   n_frames=n_frames, buffer=cell_buffer,
+                                                                   pixels_around=0, time_verbose=time_verbose)
                         # print(f"### cinac_predictor predict(): np.sum(predictions) {np.sum(predictions)}")
                         if len(predictions.shape) == 1:
                             predictions_by_cell[original_cell] = predictions
@@ -475,7 +478,7 @@ class CinacPredictor:
                     elif ("npy" in output_file_format) or ("npz" in output_file_format):
                         np.savez(os.path.join(new_dir_results, file_name + ".npz"),
                                  predictions=predictions_by_cell, cells=original_cells_to_load)
-            predictions_dict[cinac_recording.identifier] = predictions_by_cell
+            predictions_dict[(cinac_recording.identifier, network_identifier)] = predictions_by_cell
 
         return predictions_dict
 
@@ -717,7 +720,24 @@ def load_data_for_cell_type_prediction(cinac_recording, cell, sliding_window_len
 
 def predict_transient_from_model(cinac_recording, cell, model,
                                  n_frames, overlap_value=0.8, pixels_around=0,
-                                 use_data_augmentation=False, buffer=None):
+                                 use_data_augmentation=False, buffer=None,
+                                 time_verbose=True):
+    """
+
+    Args:
+        cinac_recording:
+        cell:
+        model:
+        n_frames:
+        overlap_value:
+        pixels_around:
+        use_data_augmentation:
+        buffer:
+        time_verbose: if True, print the time to predict the cell
+
+    Returns:
+
+    """
     # if n_frames is None, then the movie need to have been loaded
     # start_time = time.time()
     # multi_inputs = (model.layers[0].output_shape == model.layers[1].output_shape)
@@ -768,8 +788,9 @@ def predict_transient_from_model(cinac_recording, cell, model,
     predictions = model.predict(data_dict)
 
     stop_time = time.time()
-    print(f"Time to get predictions for cell {cell}: "
-          f"{np.round(stop_time - start_time, 3)} s")
+    if time_verbose:
+        print(f"Time to get predictions for cell {cell}: "
+              f"{np.round(stop_time - start_time, 3)} s")
 
     # now we want to take the prediction with the maximal value for a given frame
     # the rational being that often if a transient arrive right at the end or the beginning
@@ -1124,6 +1145,10 @@ def evaluate_cell_type_predictions(cinac_dir_name, cell_type_yaml_file, results_
 
             right_prediction = False
 
+            if cinac_recording.cell_type is None:
+                print(f"cinac_recording.cell_type is None for {cinac_recording.identifier}")
+                continue
+
             if cinac_recording.cell_type.strip().lower() not in cell_type_to_code_dict:
                 print(f"cinac_recording.cell_type ({cinac_recording.cell_type}) not in cell_type_to_code_dict")
                 continue
@@ -1210,11 +1235,11 @@ def evaluate_cell_type_predictions(cinac_dir_name, cell_type_yaml_file, results_
     # print(f"METRICS for {n_pyr_cell} pyramidal cells and {n_in_cell} interneurons")
     if n_class_for_predictions == 1:
         print("-" * 100)
-        print(f"Accuracy {accuracy}")
-        print(f"Sensitivity {sensitivity}")
-        print(f"Specificity {specificity}")
-        print(f"PPV {ppv}")
-        print(f"NPV {npv}")
+        print(f"Accuracy {np.round(accuracy, 3)}")
+        print(f"Sensitivity {np.round(sensitivity, 3)}")
+        print(f"Specificity {np.round(specificity, 3)}")
+        print(f"PPV {np.round(ppv, 3)}")
+        print(f"NPV {np.round(npv, 3)}")
         print("-" * 100)
     else:
         print(f"N cell classified has none of the cell types: {none_of_cell_types}")
