@@ -37,12 +37,14 @@ def create_cells_coord_from_suite_2p(is_cell_file_name, stat_file_name, movie_di
     else:
         is_cell = np.load(os.path.join(is_cell_file_name), allow_pickle=True)
 
+    pixel_masks = []
     coords = []
     for cell in np.arange(len(stat)):
         if is_cell is not None:
             if is_cell[cell][0] == 0:
                 continue
         list_points_coord = [(x, y) for x, y in zip(stat[cell]["xpix"], stat[cell]["ypix"])]
+        pixel_masks.append(list_points_coord)
         # TODO: pass the pixel_mask shape directly when available in CellsCoord
         convex_hull = MultiPoint(list_points_coord).convex_hull
         if isinstance(convex_hull, LineString):
@@ -51,7 +53,46 @@ def create_cells_coord_from_suite_2p(is_cell_file_name, stat_file_name, movie_di
             coord_shapely = MultiPoint(list_points_coord).convex_hull.exterior.coords
         coords.append(np.array(coord_shapely).transpose())
 
-    return CellsCoord(coords=coords, nb_lines=movie_dimensions[0], nb_col=movie_dimensions[1], from_matlab=False)
+    return CellsCoord(pixel_masks=pixel_masks, nb_lines=movie_dimensions[0], nb_col=movie_dimensions[1], from_matlab=False)
+
+    # return CellsCoord(coords=coords, nb_lines=movie_dimensions[0], nb_col=movie_dimensions[1], from_matlab=False)
+
+def get_coords_extracted_from_fiji(file_name):
+    """
+    Extract coords from file_name, should be z .zip or .roi file
+    Args:
+        file_name: .zip or .roi file
+
+    Returns: Array of len the number of contours made of array of 2 lines (x & y) and n columns,
+    n being the number of coordinate to set the contour of
+    each cell.
+
+    """
+    # avoid to have to install this package if not using ROIs from fiji
+    from read_roi import read_roi_file, read_roi_zip
+
+    if file_name.endswith("zip"):
+        zip_data = read_roi_zip(file_name)
+        coords_loaded = np.empty((len(zip_data),), dtype=np.object)
+        for roi_index, roi in enumerate(zip_data.values()):
+            n_points = len(roi['x'])
+            contours = np.zeros((2, n_points), dtype="int16")
+            contours[0] = roi['x']
+            contours[1] = roi['y']
+            coords_loaded[roi_index] = contours
+    elif file_name.endswith("roi"):
+        roi = read_roi_file(file_name)
+        coords_loaded = np.empty((1,), dtype=np.object)
+        roi = roi[list(roi.keys())[0]]
+        n_points = len(roi['x'])
+        contours = np.zeros((2, n_points), dtype="int16")
+        contours[0] = roi['x']
+        contours[1] = roi['y']
+        coords_loaded[0] = contours
+    else:
+        return None
+
+    return coords_loaded
 
 
 class CellsCoord:
@@ -165,7 +206,7 @@ class CellsCoord:
                 self.coords = []
                 for cell, pixel_mask in enumerate(self.pixel_masks):
                     # we use pixel_masks to build the coords, using convex_hull
-                    list_points_coord = list(zip(pixel_mask[1], pixel_mask[0]))
+                    list_points_coord = list(zip(pixel_mask[0], pixel_mask[1]))
                     convex_hull = MultiPoint(list_points_coord).convex_hull
                     if isinstance(convex_hull, LineString):
                         coord_shapely = MultiPoint(list_points_coord).convex_hull.coords
@@ -236,20 +277,34 @@ class CellsCoord:
                 #     print(f"cell_1 {poly_1.is_valid}, cell_2 {poly_2.is_valid}")
                 #     raise Exception("shapely.errors.TopologicalError")
 
-    def build_raw_traces_from_movie(self, movie):
+    def build_raw_traces_from_movie(self, movie, without_overlap=False, buffer_overlap=1):
         """
         Return a 2d array representing the fluoresence signal raw trace for each cell
         Args:
             movie: 3d array n_frames x len_y x len_x
+            without_overlap: (bool) if True, means the trace will be build only from the pixels from this cell
+            buffer_overlap: indicate from how much pixels increasing the size of overlaping cell
 
         Returns: A 2d array (n_cells * n_frames) of float
 
         """
+        buffer_overlap = max(0, buffer_overlap)
         raw_traces = np.zeros((self.n_cells, movie.shape[0]))
         for cell in np.arange(self.n_cells):
-            mask = self.get_cell_mask(cell=cell,
-                                      dimensions=(movie.shape[1], movie.shape[2]))
-            raw_traces[cell, :] = np.mean(movie[:, mask], axis=1)
+            tmp_buffer_overlap = buffer_overlap
+            while True:
+                mask = self.get_cell_mask(cell=cell,
+                                          dimensions=(movie.shape[1], movie.shape[2]),
+                                          without_overlap=without_overlap,
+                                          buffer_overlap=tmp_buffer_overlap)
+                n_pixels_in_cell = np.sum(mask)
+                if (n_pixels_in_cell > 2) or tmp_buffer_overlap == 0:
+                    break
+                tmp_buffer_overlap -= 1
+
+            # print(f"n_pixels_in_cell for cell {cell}: {n_pixels_in_cell}")
+            if n_pixels_in_cell > 0:
+                raw_traces[cell, :] = np.mean(movie[:, mask], axis=1)
         return raw_traces
 
     def build_cell_polygon_from_contour(self, cell):
@@ -277,20 +332,55 @@ class CellsCoord:
 
         # self.coords[cell] = np.array(self.cells_polygon[cell].exterior.coords).transpose()
 
-    def get_cell_mask(self, cell, dimensions):
+    def get_cell_mask(self, cell, dimensions, without_overlap=False, buffer_overlap=1):
         """
+        Return the mask of the pixels of the cell
         :param cell:
         :param dimensions: height x width
-        :return:
+        :param without_overlap: if True, means with return only the pixel belonging to this cell
+            buffer_overlap: indicate from how much pixels increasing the size of overlaping cell
+        :return: binary 2d array (movie dimension), with 1 for the pixels belonging to the cell
         """
         poly_gon = self.cells_polygon[cell]
         img = PIL.Image.new('1', (dimensions[1], dimensions[0]), 0)
-        if isinstance(poly_gon, geometry.LineString):
-            ImageDraw.Draw(img).polygon(list(poly_gon.coords), outline=1,
-                                        fill=1)
+        if (self.pixel_masks is not None) and (not without_overlap):
+            img = np.array(img)
+            pix_array = self.pixel_masks[cell]
+            for index in np.arange(pix_array.shape[1]):
+                img[pix_array[1, index], pix_array[0, index]] = 1
+            # if without_overlap and (cell in self.intersect_cells) and (len(self.intersect_cells[cell]) > 0):
+            #     for overlaping_cell in self.intersect_cells[cell]:
+            #         overlaping_poly_gon = self.cells_polygon[overlaping_cell]
+            #         # increasing the size of the cell of 1
+            #         if buffer_overlap > 0:
+            #             overlaping_poly_gon = overlaping_poly_gon.buffer(buffer_overlap)
+            #         if isinstance(overlaping_poly_gon, geometry.LineString):
+            #             ImageDraw.Draw(img).polygon(list(overlaping_poly_gon.coords), outline=0,
+            #                                         fill=0)
+            #         else:
+            #             ImageDraw.Draw(img).polygon(list(overlaping_poly_gon.exterior.coords), outline=0,
+            #                                         fill=0)
+                    # pix_array = self.pixel_masks[overlaping_cell]
+                    # for index in np.arange(pix_array.shape[1]):
+                    #     img[pix_array[1, index], pix_array[0, index]] = 0
         else:
-            ImageDraw.Draw(img).polygon(list(poly_gon.exterior.coords), outline=1,
-                                        fill=1)
+            if isinstance(poly_gon, geometry.LineString):
+                ImageDraw.Draw(img).polygon(list(poly_gon.coords), outline=1,
+                                            fill=1)
+            else:
+                ImageDraw.Draw(img).polygon(list(poly_gon.exterior.coords), outline=1,
+                                            fill=1)
+            if without_overlap and (cell in self.intersect_cells) and (len(self.intersect_cells[cell]) > 0):
+                for overlaping_cell in self.intersect_cells[cell]:
+                    overlaping_poly_gon = self.cells_polygon[overlaping_cell]
+                    if buffer_overlap > 0:
+                        overlaping_poly_gon = overlaping_poly_gon.buffer(buffer_overlap)
+                    if isinstance(overlaping_poly_gon, geometry.LineString):
+                        ImageDraw.Draw(img).polygon(list(overlaping_poly_gon.coords), outline=0,
+                                                    fill=0)
+                    else:
+                        ImageDraw.Draw(img).polygon(list(overlaping_poly_gon.exterior.coords), outline=0,
+                                                    fill=0)
         return np.array(img)
 
     def match_cells_indices(self, coord_obj, path_results, plot_title_opt=""):
