@@ -909,35 +909,13 @@ def read_cell_type_categories_yaml_file(yaml_file, using_multi_class=2):
             n_cell_categories = len(args_content)
             # if multi_class == 1, then we need a predicted_cell_type which will have the value 1
             predicted_cell_type = None
-            print(f"args_content {args_content}")
             # args_content is a list of dict, key is the cell_type name, value is a dict
             # with keywords (list of string as value) and predicted_celll_type (bool as value)
             if (multi_class_arg is None and using_multi_class == 1) or (multi_class_arg is False):
-                # for cell_type_category, category_dict in args_content.items():
-                #     if "predicted_celll_type" in category_dict:
-                #         predicted_cell_type = cell_type_category
                 for cell_type_dict in args_content:
                     for cell_type_category, category_dict in cell_type_dict.items():
                         if "predicted_celll_type" in category_dict:
                             predicted_cell_type = cell_type_category
-
-            # for cell_type_category, category_dict in args_content.items():
-            #     if (predicted_cell_type is not None) and (predicted_cell_type == cell_type_category) and \
-            #             (n_cell_categories <= 2):
-            #         cell_type_from_code_dict[1] = cell_type_category
-            #         cell_type_code = 1
-            #     else:
-            #         cell_type_from_code_dict[category_code_increment] = cell_type_category
-            #         cell_type_code = category_code_increment
-            #         print(f"cell_type_category {cell_type_category}: {cell_type_code}")
-            #         category_code_increment += 1
-            #         if (category_code_increment == 1) and (predicted_cell_type is not None) and \
-            #                 (n_cell_categories <= 2):
-            #             category_code_increment += 1
-            #     cell_type_to_code_dict[cell_type_category] = cell_type_code
-            #     if "keywords" in category_dict:
-            #         for keyword in category_dict["keywords"]:
-            #             cell_type_to_code_dict[keyword] = cell_type_code
             for cell_type_dict in args_content:
                 for cell_type_category, category_dict in cell_type_dict.items():
                     if (predicted_cell_type is not None) and (predicted_cell_type == cell_type_category) and \
@@ -947,7 +925,7 @@ def read_cell_type_categories_yaml_file(yaml_file, using_multi_class=2):
                     else:
                         cell_type_from_code_dict[category_code_increment] = cell_type_category
                         cell_type_code = category_code_increment
-                        print(f"cell_type_category {cell_type_category}: {cell_type_code}")
+                        # print(f"cell_type_category {cell_type_category}: {cell_type_code}")
                         category_code_increment += 1
                         if (category_code_increment == 1) and (predicted_cell_type is not None) and \
                                 (n_cell_categories <= 2):
@@ -959,22 +937,6 @@ def read_cell_type_categories_yaml_file(yaml_file, using_multi_class=2):
 
     return cell_type_from_code_dict, cell_type_to_code_dict, multi_class_arg
 
-    # if n_cell_categories < 2:
-    #     raise Exception(f"You need at least 2 cell_type categories, you provided {n_cell_categories}: "
-    #                     f"{list(cell_type_from_code_dict.values())}")
-    #
-    # if multi_class_arg is not None:
-    #     if multi_class_arg or (n_cell_categories > 2):
-    #         self.using_multi_class = n_cell_categories
-    #     else:
-    #         self.using_multi_class = 1
-    # else:
-    #     if n_cell_categories > 2:
-    #         self.using_multi_class = n_cell_categories
-    #     else:
-    #         self.using_multi_class = 1
-
-
 class CinacFileReader:
 
     def __init__(self, file_name, frames_to_keep=None):
